@@ -24,25 +24,25 @@
 #include <chrono>
 #include <iostream>
 
-#include <gz/physics/FindFeatures.hh>
-#include <gz/plugin/Loader.hh>
-#include <gz/physics/RequestEngine.hh>
+#include <ignition/physics/FindFeatures.hh>
+#include <ignition/plugin/Loader.hh>
+#include <ignition/physics/RequestEngine.hh>
 
 #include <ignition/math/Angle.hh>
-#include <gz/math/eigen3/Conversions.hh>
+#include <ignition/math/eigen3/Conversions.hh>
 
 // Features
 #include <ignition/physics/FrameSemantics.hh>
-#include <gz/physics/ForwardStep.hh>
+#include <ignition/physics/ForwardStep.hh>
 #include <ignition/physics/FreeGroup.hh>
-#include <gz/physics/FreeJoint.hh>
-#include <gz/physics/FixedJoint.hh>
-#include <gz/physics/GetEntities.hh>
-#include <gz/physics/Joint.hh>
-#include <gz/physics/RevoluteJoint.hh>
-#include <gz/physics/dartsim/World.hh>
-#include <gz/physics/sdf/ConstructModel.hh>
-#include <gz/physics/sdf/ConstructWorld.hh>
+#include <ignition/physics/FreeJoint.hh>
+#include <ignition/physics/FixedJoint.hh>
+#include <ignition/physics/GetEntities.hh>
+#include <ignition/physics/Joint.hh>
+#include <ignition/physics/RevoluteJoint.hh>
+#include <ignition/physics/dartsim/World.hh>
+#include <ignition/physics/sdf/ConstructModel.hh>
+#include <ignition/physics/sdf/ConstructWorld.hh>
 
 #include <limits>
 #include <sdf/Model.hh>
@@ -52,9 +52,9 @@
 #include "ignition/physics/Geometry.hh"
 #include "test/Utils.hh"
 
-using namespace gz;
+using namespace ignition;
 
-using TestFeatureList = physics::FeatureList<
+using TestFeatureList = ignition::physics::FeatureList<
   physics::dartsim::RetrieveWorld,
   physics::AttachFixedJointFeature,
   physics::DetachJointFeature,
@@ -83,14 +83,14 @@ class JointFeaturesFixture : public ::testing::Test
 {
   protected: void SetUp() override
   {
-    plugin::Loader loader;
+    ignition::plugin::Loader loader;
     loader.LoadLib(dartsim_plugin_LIB);
 
-    plugin::PluginPtr dartsim =
+    ignition::plugin::PluginPtr dartsim =
         loader.Instantiate("ignition::physics::dartsim::Plugin");
 
     this->engine =
-        physics::RequestEngine3d<TestFeatureList>::From(dartsim);
+        ignition::physics::RequestEngine3d<TestFeatureList>::From(dartsim);
     ASSERT_NE(nullptr, this->engine);
   }
   protected: TestEnginePtr engine;
@@ -743,17 +743,9 @@ TEST_F(JointFeaturesFixture, JointDetach)
   // sanity check on velocity values
   EXPECT_LT(1e-5, upperLinkLinearVelocity.Z());
   EXPECT_GT(-0.03, upperLinkAngularVelocity.X());
-#ifndef __APPLE__
-  // Disable some expectations for dartsim plugin on homebrew,
-  // see https://github.com/gazebosim/gz-physics/issues/620.
   EXPECT_NEAR(0.0, upperLinkLinearVelocity.X(), 1e-6);
-#endif
   EXPECT_NEAR(0.0, upperLinkLinearVelocity.Y(), 1e-6);
-#ifndef __APPLE__
-  // Disable some expectations for dartsim plugin on homebrew,
-  // see https://github.com/gazebosim/gz-physics/issues/620.
   EXPECT_NEAR(0.0, upperLinkAngularVelocity.Y(), 1e-6);
-#endif
   EXPECT_NEAR(0.0, upperLinkAngularVelocity.Z(), 1e-6);
 
   upperJoint->Detach();
