@@ -39,11 +39,11 @@
 #include <dart/constraint/WeldJointConstraint.hpp>
 #include <dart/dynamics/WeldJoint.hpp>
 
-#include <gz/common/Console.hh>
+#include <ignition/common/Console.hh>
 #include <ignition/common/Mesh.hh>
 #include <ignition/common/MeshManager.hh>
-#include <gz/math/eigen3/Conversions.hh>
-#include <gz/math/Helpers.hh>
+#include <ignition/math/eigen3/Conversions.hh>
+#include <ignition/math/Helpers.hh>
 
 #include <sdf/Box.hh>
 #include <sdf/Collision.hh>
@@ -164,7 +164,7 @@ static Eigen::Vector3d ConvertJointAxis(
   // Error while Resolving xyz. Fallback sdformat 1.6 behavior but treat
   // xyz_expressed_in = "__model__" as the old use_parent_model_frame
 
-  const Eigen::Vector3d axis = math::eigen3::convert(_sdfAxis->Xyz());
+  const Eigen::Vector3d axis = ignition::math::eigen3::convert(_sdfAxis->Xyz());
 
   if (_sdfAxis->XyzExpressedIn().empty())
     return axis;
@@ -395,7 +395,7 @@ Identity SDFFeatures::ConstructSdfWorld(
 
   const dart::simulation::WorldPtr &world = this->worlds.at(worldID);
 
-  world->setGravity(math::eigen3::convert(_sdfWorld.Gravity()));
+  world->setGravity(ignition::math::eigen3::convert(_sdfWorld.Gravity()));
 
   // TODO(MXG): Add a Physics class to the SDFormat DOM and then parse that
   // information here. For now, we'll just use dartsim's default physics
@@ -588,10 +588,18 @@ Identity SDFFeatures::ConstructSdfLink(
   dart::dynamics::BodyNode::Properties bodyProperties;
   bodyProperties.mName = _sdfLink.Name();
 
-  const math::Inertiald &sdfInertia = _sdfLink.Inertial();
+  const ignition::math::Inertiald &sdfInertia = _sdfLink.Inertial();
   bodyProperties.mInertia.setMass(sdfInertia.MassMatrix().Mass());
 
-  const Eigen::Matrix3d I_link = math::eigen3::convert(sdfInertia.Moi());
+  // TODO(addisu) Resolve the pose of inertials when frame information is
+  // availabile for ignition::math::Inertial
+  const Eigen::Matrix3d R_inertial{
+        math::eigen3::convert(sdfInertia.Pose().Rot())};
+
+  const Eigen::Matrix3d I_link =
+      R_inertial
+      * math::eigen3::convert(sdfInertia.Moi())
+      * R_inertial.inverse();
 
   bodyProperties.mInertia.setMoment(I_link);
 
@@ -600,8 +608,6 @@ Identity SDFFeatures::ConstructSdfLink(
 
   bodyProperties.mInertia.setLocalCOM(localCom);
 
-  bodyProperties.mGravityMode = _sdfLink.EnableGravity();
-
   dart::dynamics::FreeJoint::Properties jointProperties;
   jointProperties.mName = bodyProperties.mName + "_FreeJoint";
   // TODO(MXG): Consider adding a UUID to this joint name in order to avoid any
@@ -635,6 +641,7 @@ Identity SDFFeatures::ConstructSdfLink(
       world->getName(),
       ::sdf::JoinName(modelInfo.model->getName(), bn->getName()));
   const std::size_t linkID = this->AddLink(bn, fullName, _modelID, sdfInertia);
+  this->AddJoint(joint);
 
   auto linkIdentity = this->GenerateIdentity(linkID, this->links.at(linkID));
 
@@ -928,7 +935,7 @@ Identity SDFFeatures::ConstructSdfVisual(
   // intended for the physics?
   if (_visual.Material())
   {
-    const math::Color &color = _visual.Material()->Ambient();
+    const ignition::math::Color &color = _visual.Material()->Ambient();
     node->getVisualAspect()->setColor(
           Eigen::Vector4d(color.R(), color.G(), color.B(), color.A()));
   }
@@ -1012,11 +1019,10 @@ Identity SDFFeatures::ConstructSdfJoint(
 
   {
     auto childsParentJoint = _child->getParentJoint();
-    std::string parentName = worldParent? "world" : _parent->getName();
     if (childsParentJoint->getType() != "FreeJoint")
     {
       ignerr << "Asked to create a joint between links "
-             << "[" << parentName << "] as parent and ["
+             << "[" << _parent->getName() << "] as parent and ["
              << _child->getName() << "] as child, but the child link already "
              << "has a parent joint of type [" << childsParentJoint->getType()
              << "].\n";
@@ -1026,7 +1032,7 @@ Identity SDFFeatures::ConstructSdfJoint(
     {
       // TODO(MXG): Add support for non-tree graph structures
       ignerr << "Asked to create a closed kinematic chain between links "
-             << "[" << parentName << "] and [" << _child->getName()
+             << "[" << _parent->getName() << "] and [" << _child->getName()
              << "], but that is not supported by the dartsim wrapper yet.\n";
       return this->GenerateInvalidId();
     }
