@@ -17,7 +17,7 @@
 
 #include "Shape.hh"
 
-using namespace gz;
+using namespace ignition;
 using namespace physics;
 using namespace tpelib;
 
